#
# spec file for package python-oiffile
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oiffile
Version:        2024.5.24
Release:        2.3
Summary:        Read Olympus(r) image files (OIF and OIB)
License:        BSD-3-Clause
URL:            https://www.lfd.uci.edu/~gohlke/
# SourceRepository: https://github.com/cgohlke/oiffile
Source:         https://github.com/cgohlke/oiffile/archive/v%{version}.tar.gz#/oiffile-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module numpy >= 1.22}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tifffile >= 2021.11.2}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.22
Requires:       python-tifffile >= 2021.11.2
BuildArch:      noarch
%python_subpackages

%description
Oiffile is a Python library to read image and metadata from Olympus Image
Format files. OIF is the native file format of the Olympus FluoView(tm)
software for confocal microscopy.

%prep
%setup -q -n oiffile-%{version}
# Fix warning: wrong end-of-line encoding
sed -i 's/\r//g' README.rst

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# No test provided

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/oiffile
%{python_sitelib}/oiffile-%{version}.dist-info

%changelog
* Wed Jul 17 2024 Ben Greiner <code@bnavigator.de>
- Revert numpy pinning. Supported since 2024.5.24
* Wed Jul 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2 for now.
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.5.24:
  * Support NumPy 2.
  * Fix docstring examples not correctly rendered on GitHub.
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2023.8.30:
  * Fix linting issues.
  * Add py.typed marker.
  * Drop support for Python 3.8 and numpy < 1.22 (NEP29).
* Thu Jan 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 2022.9.29
  * Switch to Google style docstrings.
- Release 2022.2.2
  * Add type hints.
  * Add main function.
  * Add FileSystemAbc abstract base class.
  * Remove OifFile.tiffs (breaking).
  * Drop support for Python 3.7 and numpy < 1.19 (NEP29).
- Release 2021.6.6
  * Fix unclosed file warnings.
- Clean specfile
* Fri Feb 19 2021 andy great <andythe_great@pm.me>
- Skip python36 because python-numpy does not support it.
* Thu Nov 26 2020 andy great <andythe_great@pm.me>
- Update to version 2020.9.18.
  * Remove support for Python 3.6.
  * Support os.PathLike file names.
  * Fix unclosed files.
* Mon Aug 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the archive to really match up the upstream tarball
* Tue Jun  2 2020 andy great <andythe_great@pm.me>
- Update to version 2020.1.18.
  * Fix indentation error.
* Mon Mar  4 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2019.1.1
